powered by
Creates an ROIVol object representing a set of values at specific 3D coordinates within a spatial reference system.
ROIVol
ROIVol(space, coords, data)
An ROIVol object
A NeuroSpace object defining the spatial reference
NeuroSpace
A matrix with 3 columns representing (x,y,z) coordinates
A numeric vector of values corresponding to each coordinate
ROI Volume
space <- NeuroSpace(c(64,64,64)) coords <- matrix(c(1,2,3, 4,5,6), ncol=3, byrow=TRUE) data <- c(1.5, 2.5) roi_vol <- ROIVol(space, coords, data)
Run the code above in your browser using DataLab