These constants define standard anatomical axes used in neuroimaging. Each axis has a defined direction vector in 3D space.
LEFT_RIGHTRIGHT_LEFT
ANT_POST
POST_ANT
INF_SUP
SUP_INF
An object of class NamedAxis of length 1.
An object of class NamedAxis of length 1.
An object of class NamedAxis of length 1.
An object of class NamedAxis of length 1.
An object of class NamedAxis of length 1.
An object of class NamedAxis of length 1.