Learn R Programming

neuroim2 (version 0.8.5)

as: conversion from NeuroVol to LogicalNeuroVol

Description

This function provides a method to coerce an object of class ROIVec to a matrix.

This function provides a method to coerce an object of class ROIVol to a DenseNeuroVol.

Value

A matrix obtained by coercing the ROIVec object.

A DenseNeuroVol object obtained by coercing the ROIVol object.

Arguments

from

An object of class ROIVol to be coerced to a DenseNeuroVol.