Learn R Programming

neuroim2 (version 0.8.5)

as.list,FileBackedNeuroVec-method: Convert FileBackedNeuroVec to List

Description

Converts a FileBackedNeuroVec object to a list of DenseNeuroVol objects.

convert SparseNeuroVec to list of DenseNeuroVol

Usage

# S4 method for FileBackedNeuroVec
as.list(x)

# S4 method for NeuroVec as.list(x)

# S4 method for SparseNeuroVec as.list(x)

Value

A list of DenseNeuroVol objects

Arguments

x

the object

Details

This method creates a deferred list, where each element is a DenseNeuroVol object representing a single volume from the FileBackedNeuroVec.