Converts a FileBackedNeuroVec object to a list of DenseNeuroVol objects.
convert SparseNeuroVec to list of DenseNeuroVol
# S4 method for FileBackedNeuroVec
as.list(x)# S4 method for NeuroVec
as.list(x)
# S4 method for SparseNeuroVec
as.list(x)
A list of DenseNeuroVol objects
the object
This method creates a deferred list, where each element is a DenseNeuroVol object representing a single volume from the FileBackedNeuroVec.