Learn R Programming

neuroim2 (version 0.8.5)

as.sparse,DenseNeuroVec,LogicalNeuroVol-method: Convert DenseNeuroVec to sparse representation using mask

Description

This method converts a DenseNeuroVec object to a sparse representation using a given LogicalNeuroVol mask.

This method converts a DenseNeuroVec object to a sparse representation using a given numeric mask.

Usage

# S4 method for DenseNeuroVec,LogicalNeuroVol
as.sparse(x, mask)

# S4 method for DenseNeuroVec,numeric as.sparse(x, mask)

# S4 method for DenseNeuroVol,LogicalNeuroVol as.sparse(x, mask)

# S4 method for DenseNeuroVol,numeric as.sparse(x, mask)

# S4 method for ROIVol,ANY as.sparse(x)

Value

A SparseNeuroVec object resulting from the conversion.

A SparseNeuroVec object resulting from the conversion.

Arguments

x

A DenseNeuroVec object to convert to a sparse representation.

mask

A numeric vector representing the mask to apply during conversion.