Supplies an `as.vector` S4 method that flattens sparse volumes to a dense vector, keeping the same voxel ordering as `as.array`.
Usage
# S4 method for class 'SparseNeuroVol'
as.vector(x, mode = "any")Supplies an `as.vector` S4 method that flattens sparse volumes to a dense vector, keeping the same voxel ordering as `as.array`.
# S4 method for class 'SparseNeuroVol'
as.vector(x, mode = "any")