Return a matrix of centroids of an object
centroids(x, ...)# S4 method for ClusteredNeuroVec
centroids(x, type = c("center_of_mass", "medoid"))
# S4 method for ClusteredNeuroVol
centroids(x, type = c("center_of_mass", "medoid"))
A numeric matrix where each row represents the coordinates of a centroid.
A matrix of coordinates where each row represents the centroid of a cluster.
an object with multiple centroids (e.g. a ClusteredNeuroVol)
extra args
the type of center of mass: one of "center_of_mass" or "medoid"
For `type = "center_of_mass"`, returns arithmetic mean coordinates; for `"medoid"`, returns the most central point.