drop: Generic Drop Method

dropR Documentation

Generic Drop Method

Description

Provides a mechanism to remove dimensions or elements from an object.

Usage

drop(x)

Arguments

x

An object.

Value

An object of the same class as x with reduced dimensions or elements.


neuroim2 documentation built on April 16, 2026, 5:07 p.m.