Retrieve extensions with a specific extension code from a list.
Arguments
- x
A
NiftiExtensionList-classobject.- ecode
Integer extension code to filter by.
Value
A NiftiExtensionList-class containing only extensions
with the specified code.
Retrieve extensions with a specific extension code from a list.
A NiftiExtensionList-class object.
Integer extension code to filter by.
A NiftiExtensionList-class containing only extensions
with the specified code.