| [,DenseNeuroVol,numeric,missing,ANY-method | R Documentation |
This function extracts a single volume from a NeuroVec object.
Extracts a subset of data from a sparse four-dimensional brain image based on provided indices.
## S4 method for signature 'DenseNeuroVol,numeric,missing,ANY'
x[i, j, k, ..., drop = TRUE]
## S4 method for signature 'DenseNeuroVol,integer,missing,ANY'
x[i, j, k, ..., drop = TRUE]
## S4 method for signature 'NeuroVec,numeric'
x[[i]]
## S4 method for signature 'NeuroVec,character'
x[[i]]
## S4 method for signature 'NeuroVol,ROICoords,missing,ANY'
x[i, j, ..., drop = TRUE]
## S4 method for signature 'NeuroVol,ROIVol,missing,ANY'
x[i, j, k, ..., drop = TRUE]
## S4 method for signature 'DenseNeuroVol,ROIVol,missing,ANY'
x[i, j, k, ..., drop = TRUE]
## S4 method for signature 'SparseNeuroVol,numeric,numeric,ANY'
x[i, j, k, ..., drop = TRUE]
## S4 method for signature 'ROIVol,numeric,missing,ANY'
x[i, j, ..., drop = TRUE]
## S4 method for signature 'ROIVol,logical,missing,ANY'
x[i, j, k, ..., drop = TRUE]
## S4 method for signature 'ROIVol,ROICoords,missing,ANY'
x[i, j, k, ..., drop = TRUE]
## S4 method for signature 'ROIVol,matrix,missing,ANY'
x[i, j, k, ..., drop = TRUE]
## S4 method for signature 'ROIVol,missing,missing,ANY'
x[i, j, k, ..., drop = TRUE]
## S4 method for signature 'ROIVol,missing,numeric,ANY'
x[i, j, k, ..., drop = TRUE]
## S4 method for signature 'ROIVol,numeric,numeric,ANY'
x[i, j, k, ..., drop = TRUE]
## S4 method for signature 'ROIVol,logical,numeric,ANY'
x[i, j, k, ..., drop = TRUE]
## S4 method for signature 'ROIVol,ROICoords,numeric,ANY'
x[i, j, k, ..., drop = TRUE]
## S4 method for signature 'ROIVol,matrix,numeric,ANY'
x[i, j, k, ..., drop = TRUE]
## S4 method for signature 'ROICoords,numeric,missing,ANY'
x[i, j, ..., drop = TRUE]
## S4 method for signature 'ROIVol,numeric,missing,ANY'
x[i, j, ..., drop = TRUE]
## S4 method for signature 'NeuroVol,ROICoords,missing,ANY'
x[i, j, ..., drop = TRUE]
## S4 method for signature 'AbstractSparseNeuroVec,numeric,numeric,ANY'
x[i, j, k, m, ..., drop = TRUE]
x |
An object of class |
i |
Numeric vector specifying the indices for the first dimension |
j |
Numeric vector specifying the indices for the second dimension |
k |
Numeric vector specifying the indices for the third dimension (optional) |
... |
Additional arguments passed to methods |
drop |
Logical indicating whether to drop dimensions of length one (default: TRUE) |
m |
Numeric vector specifying the indices for the fourth dimension (optional) |
a DenseNeuroVol object
A subset of the input object, with dimensions depending on the indexing and the 'drop' parameter.
An array containing the extracted subset
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.