Returns the number of time points (4th dimension) in a NeuroVec object. This represents the temporal dimension of the neuroimaging data.
Returns the total number of time points across all vectors in the sequence
# S4 method for ClusteredNeuroVec
length(x)# S4 method for NeuroVec
length(x)
# S4 method for NeuroVecSeq
length(x)
# S4 method for ROIVol
length(x)
# S4 method for ROICoords
length(x)
Integer length (total number of time points)
An integer representing the number of coordinates in the ROICoords object.
A NeuroVecSeq object