Get length of NeuroVec object
Source:R/clustered_neurovec.R, R/neurovec.R, R/neurovecseq.R, and 1 more
length-methods.RdReturns the number of time points (4th dimension) in a NeuroVec object. This represents the temporal dimension of the neuroimaging data.
Returns the total number of time points across all vectors in the sequence