ndim-methods: Extract the number of dimensions of an object

ndimR Documentation

Extract the number of dimensions of an object

Description

Extract the number of dimensions of an object

Get number of dimensions in axis set

Usage

ndim(x, ...)

## S4 method for signature 'AxisSet'
ndim(x, ...)

## S4 method for signature 'ClusteredNeuroVec'
ndim(x)

## S4 method for signature 'NeuroObj'
ndim(x)

## S4 method for signature 'NeuroHyperVec'
ndim(x)

## S4 method for signature 'NeuroSpace'
ndim(x)

Arguments

x

An AxisSet object

...

Additional arguments (not used)

Value

An integer representing the number of dimensions in x.

An integer representing the number of dimensions in x.

Examples


x = NeuroSpace(c(10,10,10), spacing=c(1,1,1))
ndim(x) == 3
x = NeuroSpace(c(10,10,10,3), spacing=c(1,1,1))
ndim(x) == 4


neuroim2 documentation built on April 16, 2026, 5:07 p.m.