Extract permutation matrix associated with an image
Source:R/all_generic.R, R/axis.R
perm_mat-methods.RdA permutation matrix defines how the native voxel coordinates can be transformed to standard (LPI) orientation.
Usage
perm_mat(x, ...)
# S4 method for class 'AxisSet2D'
perm_mat(x, ...)
# S4 method for class 'AxisSet3D'
perm_mat(x, ...)
# S4 method for class 'NeuroSpace'
perm_mat(x, ...)Value
A numeric N x N matrix representing the permutation transform, where N is the dimensionality of the image.
A matrix representing the axis directions
A matrix representing the axis directions
A numeric N x N matrix representing the permutation transform, where N is the dimensionality of the image.
Details
a permutation matrix can be used to convert between cardinal image orientations. For example, if an image is stored in "RPI" (Right-Posterior-Inferior) format, a coordinate in this space can be converted to LPI (Left-Posterior-Inferior) by multiplying a coordinate vector by the permutation matrix.