Learn R Programming

neuroim2 (version 0.8.5)

scale_series: Generic functions to scale (center and/or normalize by standard deviation) each series of a 4D image That is, if the 4th dimension is 'time' each series is a 1D time series.

Description

Generic functions to scale (center and/or normalize by standard deviation) each series of a 4D image That is, if the 4th dimension is 'time' each series is a 1D time series.

Usage

scale_series(x, center, scale)

# S4 method for NeuroVec,logical,missing scale_series(x, center, scale)

# S4 method for NeuroVec,logical,logical scale_series(x, center, scale)

# S4 method for NeuroVec,missing,logical scale_series(x, center, scale)

# S4 method for NeuroVec,missing,missing scale_series(x, center, scale)

Value

An object of the same class as x, with each time series centered and/or scaled.

Arguments

x

a four dimensional image

center

a logical value indicating whether series should be centered

scale

a logical value indicating whether series should be divided by standard deviation

Examples

Run this code
bvec <- NeuroVec(array(rnorm(24*24*24*24), c(24,24,24,24)), NeuroSpace(c(24,24,24,24), c(1,1,1)))
res <- scale_series(bvec, TRUE, TRUE)

Run the code above in your browser using DataLab