Learn R Programming

neuroim2 (version 0.8.5)

spacing: Extract Voxel Dimensions of an Image

Description

This function extracts the voxel dimensions of an image represented by the input object.

Usage

spacing(x)

# S4 method for ROICoords spacing(x)

# S4 method for NeuroObj spacing(x)

# S4 method for NeuroSpace spacing(x)

Value

A numeric vector specifying the voxel dimensions of x.

Arguments

x

The object representing the image.

Examples

Run this code
bspace <- NeuroSpace(c(10, 10, 10), c(2, 2, 2))
all.equal(spacing(bspace), c(2, 2, 2))

Run the code above in your browser using DataLab