| temporal_access | R Documentation |
This function extracts one or more rows from the sparse time-by-voxel backing
representation used by sparse neuroimaging vectors. It complements
matricized_access(), which is the column-oriented accessor.
temporal_access(x, i, ...)
## S4 method for signature 'SparseNeuroVec,integer'
temporal_access(x, i)
## S4 method for signature 'SparseNeuroVec,numeric'
temporal_access(x, i)
## S4 method for signature 'BigNeuroVec,integer'
temporal_access(x, i)
## S4 method for signature 'BigNeuroVec,numeric'
temporal_access(x, i)
x |
a data source, typically a |
i |
a numeric vector of temporal indices to extract |
... |
additional arguments to be passed to methods. |
A matrix with one row per requested time index and one column per sparse voxel in the backing representation.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.