Learn R Programming

neuroim2 (version 0.8.5)

vectors: Extract an ordered list of 1D vectors.

Description

This function extracts an ordered list of 1D vectors from an object that supplies vector data. The subset argument specifies the subset of vectors to extract, and can be a vector of indices or a logical vector. The return value is a list containing the extracted vectors in the same order as the specified indices.

Usage

vectors(x, subset, ...)

# S4 method for NeuroVec,missing vectors(x)

# S4 method for DenseNeuroVec,missing vectors(x)

# S4 method for NeuroVec,numeric vectors(x, subset)

# S4 method for NeuroVec,logical vectors(x, subset)

# S4 method for NeuroVecSeq,missing vectors(x)

# S4 method for NeuroVecSeq,numeric vectors(x, subset)

# S4 method for NeuroVecSeq,logical vectors(x, subset)

# S4 method for ROIVec,missing vectors(x)

# S4 method for matrix,missing vectors(x)

# S4 method for ROIVec,integer vectors(x, subset)

# S4 method for matrix,integer vectors(x, subset)

# S4 method for matrix,numeric vectors(x, subset)

# S4 method for ROIVec,numeric vectors(x, subset)

# S4 method for ROIVec,logical vectors(x, subset)

# S4 method for SparseNeuroVec,missing vectors(x, nonzero = FALSE)

Value

A list containing the extracted vectors from x in the same order as subset.

A deflist object where each element is a function that returns the time series for a voxel. The length of the deflist equals the total number of voxels.

Arguments

x

the object that supplies the vector data.

subset

the subset of vectors to extract.

...

additional arguments to be passed to methods.

nonzero

only include nonzero vectors in output list

Examples

Run this code

file_name <- system.file("extdata", "global_mask_v4.nii", package="neuroim2")
vec <- read_vec(file_name)
v <- vectors(vec)
mean(v[[1]])

Run the code above in your browser using DataLab