| ClusteredNeuroVec-class | R Documentation |
A class representing a 4D neuroimaging dataset where voxels are grouped into clusters. Each cluster has a single time-series that is shared by all voxels within that cluster.
cvolA ClusteredNeuroVol object defining cluster assignments
tsA numeric matrix of dimensions T x K (time points x clusters)
cl_mapAn integer vector mapping each voxel to its cluster ID (0 for outside mask)
labelA character string label for the object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.