NeuroObj-class: NeuroObj Class

NeuroObj-classR Documentation

NeuroObj Class

Description

Base class for all neuroimaging data objects with a Cartesian spatial representation. This class provides a foundation for more specific neuroimaging data structures.

Slots

space

An object of class NeuroSpace representing the geometry of the image object.

See Also

NeuroSpace-class, NeuroSlice-class, NeuroVol-class


neuroim2 documentation built on April 16, 2026, 5:07 p.m.