Base class for all neuroimaging data objects with a Cartesian spatial representation.
This class provides a foundation for more specific neuroimaging data structures.
Arguments
Slots
space
An object of class NeuroSpace representing the geometry of the image object.