Learn R Programming

neuroim2 (version 0.8.5)

NiftiExtensionList-class: NiftiExtensionList Class

Description

A validated list containing zero or more NiftiExtension-class objects. This class ensures type safety when working with collections of NIfTI extensions.

Usage

# S4 method for NiftiExtensionList
show(object)

Arguments

object

A NiftiExtensionList object.

Details

The class extends list and enforces that all elements must be NiftiExtension objects. This provides a clean container for managing multiple extensions attached to a NIfTI file.

See Also

NiftiExtension-class for individual extension objects. extensions for accessing extensions from image objects.

Examples

Run this code
# Create an empty extension list
ext_list <- new("NiftiExtensionList")

# Create a list with extensions
ext1 <- NiftiExtension(ecode = 6L, data = "Comment 1")
ext2 <- NiftiExtension(ecode = 6L, data = "Comment 2")
ext_list <- new("NiftiExtensionList", list(ext1, ext2))

Run the code above in your browser using DataLab