powered by
NeuroVol
LogicalNeuroVol
This function provides a method to coerce an object of class ROIVec to a matrix.
ROIVec
matrix
This function provides a method to coerce an object of class ROIVol to a DenseNeuroVol.
ROIVol
DenseNeuroVol
A matrix obtained by coercing the ROIVec object.
A DenseNeuroVol object obtained by coercing the ROIVol object.
An object of class ROIVol to be coerced to a DenseNeuroVol.