Convert ClusteredNeuroVol to a base array
Source:R/clustervol.R, R/neurovol.R, R/sparse_neurovec.R
as.array-methods.RdEnsures that clustered volumes dispatch through the `as.array` S4 generic and return dense arrays of cluster labels aligned to the underlying space.
Provides an `as.array` S4 method so sparse volumes can be coerced with the same syntax used for dense objects.