| as.array,ClusteredNeuroVol-method | R Documentation |
Ensures that clustered volumes dispatch through the 'as.array' S4 generic and return dense arrays of cluster labels aligned to the underlying space.
Provides an 'as.array' S4 method so sparse volumes can be coerced with the same syntax used for dense objects.
## S4 method for signature 'ClusteredNeuroVol'
as.array(x, ...)
## S4 method for signature 'SparseNeuroVol'
as.array(x, ...)
## S4 method for signature 'SparseNeuroVec'
as.array(x, ...)
x |
A SparseNeuroVec object. |
... |
Additional arguments (currently ignored). |
A dense array of cluster ids.
A dense array with voxel values at their spatial locations and zeros elsewhere.
A dense 4D array with sparse values inserted at mask indices and zeros elsewhere.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.