Learn R Programming

neuroim2 (version 0.8.1)

as.dense,ClusteredNeuroVol-method: Coerce ROIVol to DenseNeuroVol using as.dense method

Description

This function provides a method to coerce an object of class ROIVol to a DenseNeuroVol using the as.dense method.

Usage

# S4 method for ClusteredNeuroVol
as.dense(x)

# S4 method for ROIVol as.dense(x)

# S4 method for SparseNeuroVec as.dense(x)

Value

A NeuroVol object representing the dense version of the clustered volume.

A DenseNeuroVol object obtained by coercing the ROIVol object.

Arguments

x

An object of class ROIVol to be coerced to a DenseNeuroVol.