| as.dense,ClusteredNeuroVol-method | R Documentation |
Materializes a NeuroVecSeq as a single
DenseNeuroVec with the sequence's combined space.
Convert a sparse volumetric image to a dense representation with the same spatial geometry. Non-zero values stored in the sparse vector are placed at their corresponding linear indices in the dense array; all other voxels are 0.
Identity method: returns a DenseNeuroVol (or subclass such
as LogicalNeuroVol) unchanged.
This function provides a method to coerce an object of class ROIVol to a DenseNeuroVol using the as.dense method.
## S4 method for signature 'ClusteredNeuroVol'
as.dense(x)
## S4 method for signature 'NeuroVecSeq'
as.dense(x)
## S4 method for signature 'SparseNeuroVol'
as.dense(x)
## S4 method for signature 'DenseNeuroVol'
as.dense(x)
## S4 method for signature 'ROIVol'
as.dense(x)
## S4 method for signature 'SparseNeuroVec'
as.dense(x)
x |
An object of class |
A NeuroVol object representing the dense version of the clustered volume.
A DenseNeuroVec containing all sequence volumes concatenated in time.
A DenseNeuroVol with identical spatial dimensions and values expanded from the sparse representation.
A DenseNeuroVol object obtained by coercing the ROIVol object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.