This method converts a DenseNeuroVec object to a sparse representation using a given LogicalNeuroVol mask.
This method converts a DenseNeuroVec object to a sparse representation using a given numeric mask.
# S4 method for DenseNeuroVec,LogicalNeuroVol
as.sparse(x, mask)# S4 method for DenseNeuroVec,numeric
as.sparse(x, mask)
# S4 method for DenseNeuroVol,LogicalNeuroVol
as.sparse(x, mask)
# S4 method for DenseNeuroVol,numeric
as.sparse(x, mask)
# S4 method for ROIVol,ANY
as.sparse(x)
A SparseNeuroVec object resulting from the conversion.
A SparseNeuroVec object resulting from the conversion.
A DenseNeuroVec object to convert to a sparse representation.
A numeric vector representing the mask to apply during conversion.