powered by
This function returns the length of a given axis (dimension) of an object. The axis can be specified using its position or name.
dim_of(x, axis)# S4 method for NeuroSpace,NamedAxis dim_of(x, axis)
# S4 method for NeuroSpace,NamedAxis dim_of(x, axis)
An integer representing the length of the specified axis of x.
axis
x
The NeuroSpace object
The NamedAxis to query
x <- NeuroSpace(c(10,10,10), spacing=c(1,1,1)) stopifnot(dim_of(x, x@axes@i) == 10)
Run the code above in your browser using DataLab