Learn R Programming

neuroim2 (version 0.8.5)

get_afni_attribute: Get AFNI Attribute from Extension

Description

Extracts a specific attribute value from a parsed AFNI extension.

Usage

get_afni_attribute(ext, attr_name)

Value

The attribute value, or NULL if not found. The type depends on the attribute's ni_type in the XML.

Arguments

ext

A NiftiExtension-class object with ecode = 4, or an xml_document from parse_afni_extension.

attr_name

Character string specifying the attribute name to retrieve (e.g., "HISTORY_NOTE", "BRICK_LABS").

Examples

Run this code
if (FALSE) {
# Get the history note from an AFNI extension
history <- get_afni_attribute(afni_ext, "HISTORY_NOTE")
}

Run the code above in your browser using DataLab