powered by
Extracts a specific attribute value from a parsed AFNI extension.
get_afni_attribute(ext, attr_name)
The attribute value, or NULL if not found. The type depends on the attribute's ni_type in the XML.
A NiftiExtension-class object with ecode = 4, or an xml_document from parse_afni_extension.
NiftiExtension-class
parse_afni_extension
Character string specifying the attribute name to retrieve (e.g., "HISTORY_NOTE", "BRICK_LABS").
if (FALSE) { # Get the history note from an AFNI extension history <- get_afni_attribute(afni_ext, "HISTORY_NOTE") }
Run the code above in your browser using DataLab