read_vol_list: read_vol_list
Description
This function loads a list of image volumes and returns a NeuroVec object.
Usage
read_vol_list(file_names, mask = NULL)
Value
An instance of the NeuroVec class.
Arguments
- file_names
A list of file names to load.
- mask
An optional mask defining the subset of voxels to load.