powered by
This function extracts the voxel dimensions of an image represented by the input object.
spacing(x)# S4 method for ROICoords spacing(x)# S4 method for NeuroObj spacing(x)# S4 method for NeuroSpace spacing(x)
# S4 method for ROICoords spacing(x)
# S4 method for NeuroObj spacing(x)
# S4 method for NeuroSpace spacing(x)
A numeric vector specifying the voxel dimensions of x.
x
The object representing the image.
bspace <- NeuroSpace(c(10, 10, 10), c(2, 2, 2)) all.equal(spacing(bspace), c(2, 2, 2))
Run the code above in your browser using DataLab