This function extracts an ordered series of 3D volumes from an object that supplies volume data.
The indices argument specifies the subset of volumes to extract, and can be a vector
of indices or a logical vector. The return value is a list containing the extracted volumes
in the same order as the specified indices.
Usage
vols(x, indices, ...)
# S4 method for NeuroVec,numeric
vols(x, indices)
# S4 method for NeuroVec,missing
vols(x)
Value
A list containing the extracted 3D volumes from x in the same order as indices.